@@ -13,7 +13,7 @@ use Archive::Tar;
 use IO::Scalar;
 use IO::String;
 
-our $VERSION = '3.000004';
+our $VERSION = '3.000010';
 
 our @SUITE_HEADER_KEYS_GENERAL = qw(suite-version
                                     hardwaredb-systems-id
@@ -496,7 +496,8 @@ sub _fix_generated_html
 
         $html =~ s/^.*<body>//msg; # cut start
         $html =~ s,<div id="footer">Generated by TAP::Formatter::HTML[^<]*</div>,,msg; # cut footer
-        $html =~ s,<div id="menu">[\t\n\s]*<li>[\t\n\s]*<span id="show-all"><a href="#" title="show all tests">show all</a></span>[\t\n\s]*<span id="show-failed"><a href="#" title="show failed tests only">show failed</a></span>[\t\n\s]*</li>[\t\n\s]*</div>,,msg; # cut navi
+        # cut navigation that was meant for standalone html pages, not needed by us
+        $html =~ s,<div id="menu">[\t\n\s]*<ul>[\t\n\s]*<li>[\t\n\s]*<span id="show-all">[\t\n\s]*<a href="#" title="show all tests">show all</a>[\t\n\s]*</span>[\t\n\s]*<span id="show-failed">[\t\n\s]*<a href="#" title="show failed tests only">show failed</a>[\t\n\s]*</span>[\t\n\s]*</li>[\t\n\s]*</ul>[\t\n\s]*</div>,,msg;
         $html =~ s,<th class="time">Time</th>,<th class="time">&nbsp;</th>,msg; # cut "Time" header
 
         return $html;
